# This line of code will allow shorter imports
from dsa_alg.search import Search